@@ -7,6 +7,9 @@ test_that("regular use", {
 
   expect_equal(rs$get_state(), "idle")
 
+  ## Clean session
+  expect_identical(rs$run(function() ls(.GlobalEnv)), character())
+
   ## Start a command
   rs$call(function() 42)
 
@@ -261,6 +264,10 @@ test_that("traceback", {
   }
 
   expect_error(rs$run(do), "oops")
-  expect_output(tb <- rs$traceback(), "1: f() at ", fixed = TRUE)
-  if (getRversion() >= "3.3.0") expect_equal(c(tb[[4]]), "f()")
+  expect_output(tb <- rs$traceback(), "1: \"?f()\"?")
+  if (getRversion() >= "3.7.0") {
+    expect_equal(c(tb[[4]]), "\"f()\"")
+  } else if (getRversion() >= "3.3.0") {
+    expect_equal(c(tb[[4]]), "f()")
+  }
 })
